Package: config
Type: Package
Title: Manage Environment Specific Configuration Values
Version: 0.3
Authors@R: c(
  person("JJ", "Allaire", role = c("aut", "cre"), email = "jj@rstudio.com"),
  person(family = "RStudio, Inc.", role = "cph"))
Imports: yaml (>= 2.1.13)
Suggests: testthat, knitr
Description: Manage configuration values across multiple environments (e.g.
  development, test, production). Read values using a function that determines
  the current environment and returns the appropriate value.
License: GPL-3
URL: https://github.com/rstudio/config
BugReports: https://github.com/rstudio/config/issues
RoxygenNote: 6.0.1
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2018-03-27 17:50:45 UTC; jjallaire
Author: JJ Allaire [aut, cre],
  RStudio, Inc. [cph]
Maintainer: JJ Allaire <jj@rstudio.com>
Repository: CRAN
Date/Publication: 2018-03-27 20:38:53 UTC
Built: R 3.4.1; ; 2018-09-09 23:04:32 UTC; windows
